package fr.ippon.geohipster.service.impl;

import fr.ippon.geohipster.service.GeocityService;
import fr.ippon.geohipster.domain.Geocity;
import fr.ippon.geohipster.repository.GeocityRepository;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;


/**
 * Service Implementation for managing Geocity.
 */
@Service
@Transactional
public class GeocityServiceImpl implements GeocityService{

    private final Logger log = LoggerFactory.getLogger(GeocityServiceImpl.class);

    private final GeocityRepository geocityRepository;

    public GeocityServiceImpl(GeocityRepository geocityRepository) {
        this.geocityRepository = geocityRepository;
    }

    /**
     * Save a geocity.
     *
     * @param geocity the entity to save
     * @return the persisted entity
     */
    @Override
    public Geocity save(Geocity geocity) {
        log.debug("Request to save Geocity : {}", geocity);
        return geocityRepository.save(geocity);
    }

    /**
     *  Get all the geocities.
     *
     *  @param pageable the pagination information
     *  @return the list of entities
     */
    @Override
    @Transactional(readOnly = true)
    public Page<Geocity> findAll(Pageable pageable) {
        log.debug("Request to get all Geocities");
        return geocityRepository.findAll(pageable);
    }

    /**
     *  Get one geocity by id.
     *
     *  @param id the id of the entity
     *  @return the entity
     */
    @Override
    @Transactional(readOnly = true)
    public Geocity findOne(Long id) {
        log.debug("Request to get Geocity : {}", id);
        return geocityRepository.findOne(id);
    }

    /**
     *  Delete the  geocity by id.
     *
     *  @param id the id of the entity
     */
    @Override
    public void delete(Long id) {
        log.debug("Request to delete Geocity : {}", id);
        geocityRepository.delete(id);
    }
}
