import { Injectable } from '@angular/core';
import { Http, Response } from '@angular/http';
import { Observable } from 'rxjs/Rx';

import { Geocity } from './geocity.model';
import { ResponseWrapper, createRequestOption } from '../../shared';

@Injectable()
export class GeocityService {

    private resourceUrl = 'api/geocities';

    constructor(private http: Http) { }

    create(geocity: Geocity): Observable<Geocity> {
        const copy = this.convert(geocity);
        return this.http.post(this.resourceUrl, copy).map((res: Response) => {
            return res.json();
        });
    }

    update(geocity: Geocity): Observable<Geocity> {
        const copy = this.convert(geocity);
        return this.http.put(this.resourceUrl, copy).map((res: Response) => {
            return res.json();
        });
    }

    find(id: number): Observable<Geocity> {
        return this.http.get(`${this.resourceUrl}/${id}`).map((res: Response) => {
            return res.json();
        });
    }

    query(req?: any): Observable<ResponseWrapper> {
        const options = createRequestOption(req);
        return this.http.get(this.resourceUrl, options)
            .map((res: Response) => this.convertResponse(res));
    }

    delete(id: number): Observable<Response> {
        return this.http.delete(`${this.resourceUrl}/${id}`);
    }

    private convertResponse(res: Response): ResponseWrapper {
        const jsonResponse = res.json();
        return new ResponseWrapper(res.headers, jsonResponse, res.status);
    }

    private convert(geocity: Geocity): Geocity {
        const copy: Geocity = Object.assign({}, geocity);
        return copy;
    }
}
